==> piwigo-2.5.1.zip: piwigo/language/gl_ES/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'os nomes das táboas da base de datos irán prefixadas con el (permite unha mellor xestión das táboas)';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['enter a login for webmaster'] = 'insire o nome de usuario do administrador web';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'o enderezo de correo debe ter o formato xxx@yyy.eee (exemplo: proxecto@trasno.net';
$lang['please enter your password again'] = 'insire a túa clave outra vez';
$lang['user login given by your host provider'] = 'nome de usuario fornecido polo teu provedor do aloxamento';
$lang['user password given by your host provider'] = 'clave de usuario fornecida polo teu provedor do aloxamento';
$lang['verification'] = 'verificación';
$lang['webmaster login can\'t contain characters \' or "'] = 'o nome de usuario do administrador web non pode conter caranteres \' nin "';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Tes que poñerte en contacto co teu fornecedor do aloxamento coa fin de saber como mudar a PHP 5.';
$lang['also given by your host provider'] = 'tamén fornecido polo teu provedor do aloxamento';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo pode tratar de mudar a túa configuración PHP 5 a traveso da creación ou modificación dun ficheiro .htaccess.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo non foi quen de configurar o PHP 5.';
$lang['Sorry!'] = 'Sentímolo!';
$lang['Start Install'] = 'Comezar a instalación';
$lang['Try to configure PHP 5'] = 'Tratar de configurar PHP 5';
$lang['User'] = 'Usuario';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Os visitantes poderán empregar este correo electrónico para contactar co administrador do sitio';
$lang['Webmaster login'] = 'Usuario do administrador web';
$lang['Webmaster mail address'] = 'Correo electrónico do administrador web';
$lang['Webmaster password'] = 'Clave do administrador web';
$lang['Welcome to my photo gallery'] = 'Benvido a miña galería de fotos';
$lang['Welcome to your new installation of Piwigo!'] = 'Benvido a túa nova instalación de piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Podes descargar o ficheiro de configuración e subilo a local/config na túa instalación.';
$lang['PHP 5 is required'] = 'É preciso PHP 5';
$lang['Password'] = 'Clave';
$lang['Password ']['confirm'] = 'Clave [confirmar]';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Fíxate que podes mudar ti mesmo a túa configuración e reiniciar o Piwigo despois.';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Precisas axuda? Pregunta as túas dúbidas no <a href="%s">panel de mensaxes Piwigo</a>. ';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Mantéñaa ben gardada, é ela a que lle permite acceder ó panel da administración';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Será amosado ós visitantes. É preciso para a administración do sito web';
$lang['Just another Piwigo gallery'] = 'Só outra galería Piwigo';
$lang['It appears your webhost is currently running PHP %s.'] = 'Parece que o teu servidor web ten a versión PHP %s.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Non dubides en escribir nos nosos foros para calquera dúbida: %s';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Unha solución alternativa será copiar o texto da caixa de abaixo e pegalo no ficheiro "local/config/database.inc.php" (Atención: database.inc.php só deberá conter o texto que está na caixa, non insiras ningunha liña nova ou espazo en branco)';
$lang['Basic configuration'] = 'Configuración básica';
$lang['Can\'t connect to server'] = 'Non foi posible conectar co servidor';
$lang['Congratulations, Piwigo installation is completed'] = 'Grazas, a instalación de Piwigo completouse';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'A conexión co servidor foi satisfactoria mentres que a conexión coa base de datos non foi posible.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'A creación do ficheiro de configuración local/config/database.inc.php fallou.';
$lang['Database configuration'] = 'Configuración da base de datos';
$lang['Database name'] = 'Nome da base de datos';
$lang['Database table prefix'] = 'Prefixo das táboas na base de datos';
$lang['Default gallery language'] = 'Idioma predeterminado da galería';
$lang['Download the config file'] = 'Descargar o ficheiro de configuración';
$lang['Hope to see you back soon.'] = 'Esperamos verte de volta en breve.';
$lang['Host'] = 'Servidor';
$lang['Installation'] = 'Instalación';
$lang['Admin configuration'] = 'Configuración da adminstración';
?>

==> piwigo-2.7.4.zip: piwigo/language/gl_ES/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'os nomes das táboas da base de datos irán prefixadas con el (permite unha mellor xestión das táboas)';
$lang['enter a login for webmaster'] = 'insire o nome de usuario do administrador web';
$lang['please enter your password again'] = 'insire a túa clave outra vez';
$lang['user login given by your host provider'] = 'nome de usuario fornecido polo teu provedor do aloxamento';
$lang['user password given by your host provider'] = 'clave de usuario fornecida polo teu provedor do aloxamento';
$lang['verification'] = 'verificación';
$lang['webmaster login can\'t contain characters \' or "'] = 'o nome de usuario do administrador web non pode conter caranteres \' nin "';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Tes que poñerte en contacto co teu fornecedor do aloxamento coa fin de saber como mudar a PHP 5.';
$lang['also given by your host provider'] = 'tamén fornecido polo teu provedor do aloxamento';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo pode tratar de mudar a túa configuración PHP 5 a traveso da creación ou modificación dun ficheiro .htaccess.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo non foi quen de configurar o PHP 5.';
$lang['Sorry!'] = 'Sentímolo!';
$lang['Start Install'] = 'Comezar a instalación';
$lang['Try to configure PHP 5'] = 'Tratar de configurar PHP 5';
$lang['User'] = 'Usuario';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Os visitantes poderán empregar este correo electrónico para contactar co administrador do sitio';
$lang['Welcome to my photo gallery'] = 'Benvido a miña galería de fotos';
$lang['Welcome to your new installation of Piwigo!'] = 'Benvido a túa nova instalación de piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Podes descargar o ficheiro de configuración e subilo a local/config na túa instalación.';
$lang['PHP 5 is required'] = 'É preciso PHP 5';
$lang['Password ']['confirm'] = 'Clave [confirmar]';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Fíxate que podes mudar ti mesmo a túa configuración e reiniciar o Piwigo despois.';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Precisas axuda? Pregunta as túas dúbidas no <a href="%s">panel de mensaxes Piwigo</a>. ';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Mantéñaa ben gardada, é ela a que lle permite acceder ó panel da administración';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Será amosado ós visitantes. É preciso para a administración do sito web';
$lang['Just another Piwigo gallery'] = 'Só outra galería Piwigo';
$lang['It appears your webhost is currently running PHP %s.'] = 'Parece que o teu servidor web ten a versión PHP %s.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Non dubides en escribir nos nosos foros para calquera dúbida: %s';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Unha solución alternativa será copiar o texto da caixa de abaixo e pegalo no ficheiro "local/config/database.inc.php" (Atención: database.inc.php só deberá conter o texto que está na caixa, non insiras ningunha liña nova ou espazo en branco)';
$lang['Basic configuration'] = 'Configuración básica';
$lang['Can\'t connect to server'] = 'Non foi posible conectar co servidor';
$lang['Congratulations, Piwigo installation is completed'] = 'Grazas, a instalación de Piwigo completouse';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'A conexión co servidor foi satisfactoria mentres que a conexión coa base de datos non foi posible.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'A creación do ficheiro de configuración local/config/database.inc.php fallou.';
$lang['Database configuration'] = 'Configuración da base de datos';
$lang['Database name'] = 'Nome da base de datos';
$lang['Database table prefix'] = 'Prefixo das táboas na base de datos';
$lang['Default gallery language'] = 'Idioma predeterminado da galería';
$lang['Download the config file'] = 'Descargar o ficheiro de configuración';
$lang['Hope to see you back soon.'] = 'Esperamos verte de volta en breve.';
$lang['Host'] = 'Servidor';
$lang['Installation'] = 'Instalación';
$lang['Admin configuration'] = 'Configuración da adminstración';
$lang['localhost or other, supplied by your host provider'] = 'aloxamento local ou outro, fornecido polo seu aloxador';
?>
